@@ -11,41 +11,104 @@ use Carp;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw/
 	create_read_struct
+	create_read_struct
+	create_write_struct
 	create_write_struct
 	destroy_read_struct
+	destroy_read_struct
 	destroy_write_struct
+	destroy_write_struct
+	write_png
 	write_png
 	init_io
 	read_info
 	read_update_info
 	read_image
+	read_image
+	read_png
 	read_png
 	get_text
+	get_text
+	set_text
 	set_text
 	sig_cmp
+	sig_cmp
 	scalar_as_input
+	scalar_as_input
+	read_from_scalar
+	read_from_scalar
+	color_type_name
+	color_type_name
+	text_compression_name
+	text_compression_name
 	get_libpng_ver
 	access_version_number
+	get_row_pointers
+	get_row_pointers
+	get_rows
+	get_rows
+	get_rowbytes
+	get_valid
 	get_valid
 	set_tRNS_pointer
+	set_tRNS_pointer
 	set_rows
+	set_rows
+	write_to_scalar
 	write_to_scalar
 	set_filter
 	set_verbosity
+	set_verbosity
+	set_unknown_chunks
 	set_unknown_chunks
 	get_unknown_chunks
+	get_unknown_chunks
+	libpng_supports
 	libpng_supports
 	set_keep_unknown_chunks
+	set_keep_unknown_chunks
+	get_tRNS_palette
 	get_tRNS_palette
 	set_expand
 	set_gray_to_rgb
 	set_filler
+	get_sRGB
+	get_sRGB
 	set_sRGB
 	set_packing
 	set_strip_16
 	get_internals
 	set_transforms
+	set_transforms
 	copy_row_pointers
+	copy_row_pointers
+	set_rgb_to_gray
+	set_rgb_to_gray
+	get_channels
+	get_channels
+	get_bit_depth
+	get_interlace_type
+	get_color_type
+	set_user_limits
+	set_user_limits
+	set_image_data
+	set_row_pointers
+	set_rgb_to_gray_fixed
+	set_compression_level
+	set_compression_buffer_size
+	get_compression_buffer_size
+	set_compression_mem_level
+	set_compression_strategy
+	set_compression_window_bits
+	set_text_compression_level
+	set_text_compression_mem_level
+	set_text_compression_strategy
+	set_text_compression_window_bits
+	set_compression_method
+	set_crc_action
+	split_alpha
+	split_alpha
+	read_struct
 	get_bKGD
 	set_bKGD
 	get_cHRM
@@ -93,7 +156,7 @@ our %EXPORT_TAGS = (
 );
 
 require XSLoader;
-our $VERSION = '0.49_03';
+our $VERSION = '0.49_04';
 
 XSLoader::load('Image::PNG::Libpng', $VERSION);
 
@@ -134,6 +197,22 @@ sub read_png_file
 sub write_png_file
 {
     my ($png, $file_name) = @_;
+    if ($png->read_struct ()) {
+
+	# The following is more convenient but might not work in some
+	# cases, depending on how libpng handles different
+	# transformations and so on, so I don't really want to risk
+	# it.
+
+	# my $copy = $png->copy_png ();
+	# write_png_file ($copy, $file_name);
+	# return;
+
+	croak "The png is a read structure, use copy_png to copy it to a write structure";
+    }
+    if (! $file_name) {
+	croak "Supply a file name";
+    }
     open my $in, ">:raw", $file_name
         or croak "Cannot open '$file_name' for writing: $!";
     $png->init_io ($in);
